@@ -646,8 +646,8 @@ mkinfit <- function(mkinmod, observed,
 
       if (cost < cost.current) {
         assign("cost.current", cost, inherits = TRUE)
-        if (!quiet) cat(ifelse(OLS, "Sum of squared residuals", "Negative log-likelihood"),
-                        " at call ", calls, ": ", signif(cost.current, 6), "\n", sep = "")
+        if (!quiet) message(ifelse(OLS, "Sum of squared residuals", "Negative log-likelihood"),
+                        " at call ", calls, ": ", signif(cost.current, 6), "\n")
       }
     }
     return(cost)
